from setuptools import setup, find_packages

setup(
    name='addtestpypi',
    version='2.0.3',
    packages=find_packages(),
    install_requires=[],  # We don't have any dependencies for this example
    author='Yamini',
    author_email='kyamini21@gmail.com',
    description='A simple library for adding numbers',
    url='https://github.com/yamini-2195/addtestpypi',
)
